import pymug

def main():
    print('Greetings From The Pymug (Python Mauritius User Group)')
    print('github.com/pymug')

print('pymug says hello main')

if __name__ == '__main__':
    main()